==> concierge-1.0.0-sources.jar: com/flybits/concierge/ConciergeConstants.java <==
package com.flybits.concierge;

public class ConciergeConstants {
    public static final String AUDIO_CONTENT_TYPE = "ctn-flybits-concierge-audio";
    public static final String ONBOARDING_CONTENT_TYPE = "ctn-flybits-concierge-onboarding";
    public static final String EVENT_CONTENT_TYPE = "ctn-flybits-concierge-event";
    public static final String ARTICLE_CONTENT_TYPE = "ctn-flybits-concierge-article";
    public static final String IMAGE_CONTENT_TYPE = "ctn-flybits-concierge-image";
    public static final String SURVEY_CONTENT_TYPE = "SurveyQuestions";
    public static final String SCHEDULE_CONTENT_TYPE = "ctn-flybits-concierge-schedule";
    public static final String TEXT_CONTENT_TYPE = "ctn-flybits-concierge-text";
    public static final String TWITTER_CONTENT_TYPE = "ctn-flybits-concierge-twitter";
    public static final String VIDEO_CONTENT_TYPE = "ctn-flybits-concierge-video";
    public static final String LINK_CONTENT_TYPE = "ctn-flybits-concierge-link";

    public static final String BROADCAST_AUDIO_STATE = "flybits_con_broadcast_audio_state";
    public static final String INTENT_EXTRA_AUDIO_STATE = "flybits_con_intent_extra_audio_state";

    public static final String BROADCAST_CONTENT_ADD = "flybits_con_broadcast_content_add";
    public static final String BROADCAST_CONTENT_REMOVE = "flybits_con_broadcast_content_remove";
    public static final String BROADCAST_CONTENT_UPDATE = "flybits_con_broadcast_content_update";
    public static final String BROADCAST_RULE_UPDATE = "flybits_con_broadcast_rule_update";
    public static final String BROADCAST_RULE_STATE = "flybits_con_broadcast_rule_state";

    public static final String BROADCAST_OPT_OUT = "flybits_con_broadcast_opt_out";

    public static final String PUSH_CONTENT_ID = "flybits_con_push_content_id";
    public static final String PUSH_CONTENT_URL = "flybits_con_push_content_url";
    public static final String PUSH_ID = "flybits_con_push_id";

    public static final String STATE_ERROR_PRESENT = "flybits_con_error_present";
    public static final String STATE_LOADING = "flybits_con_loading";
    public static final String STATE_URL = "flybits_con_url";

    public static final String SURVEY_QUESTION_REQUIRED = "isRequired";
}

==> concierge-1.4.1-sources.jar: com/flybits/concierge/ConciergeConstants.java <==
package com.flybits.concierge;

public class ConciergeConstants {
    public static final String AUDIO_CONTENT_TYPE = "ctn-flybits-concierge-audio";
    public static final String ONBOARDING_CONTENT_TYPE = "ctn-flybits-concierge-onboarding";
    public static final String EVENT_CONTENT_TYPE = "ctn-flybits-concierge-event";
    public static final String ARTICLE_CONTENT_TYPE = "ctn-flybits-concierge-article";
    public static final String IMAGE_CONTENT_TYPE = "ctn-flybits-concierge-image";
    public static final String SURVEY_CONTENT_TYPE = "SurveyQuestions";
    public static final String SCHEDULE_CONTENT_TYPE = "ctn-flybits-concierge-schedule";
    public static final String TEXT_CONTENT_TYPE = "ctn-flybits-concierge-text";
    public static final String TWITTER_CONTENT_TYPE = "ctn-flybits-concierge-twitter";
    public static final String VIDEO_CONTENT_TYPE = "ctn-flybits-concierge-video";
    public static final String LINK_CONTENT_TYPE = "ctn-flybits-concierge-link";

    public static final String BROADCAST_AUDIO_STATE = "flybits_con_broadcast_audio_state";
    public static final String INTENT_EXTRA_AUDIO_STATE = "flybits_con_intent_extra_audio_state";

    public static final String BROADCAST_CONTENT_ADD = "flybits_con_broadcast_content_add";
    public static final String BROADCAST_CONTENT_REMOVE = "flybits_con_broadcast_content_remove";
    public static final String BROADCAST_CONTENT_UPDATE = "flybits_con_broadcast_content_update";
    public static final String BROADCAST_RULE_UPDATE = "flybits_con_broadcast_rule_update";
    public static final String BROADCAST_RULE_STATE = "flybits_con_broadcast_rule_state";

    public static final String BROADCAST_OPT_OUT = "flybits_con_broadcast_opt_out";

    public static final String BROADCAST_PUSH_ENGAGED = "flybits_con_broadcast_push_engaged";

    public static final String PUSH_EXTRA = "flybits_con_push_extra";

    public static final String STATE_ERROR_PRESENT = "flybits_con_error_present";
    public static final String STATE_LOADING = "flybits_con_loading";
    public static final String STATE_URL = "flybits_con_url";

    public static final String SURVEY_QUESTION_REQUIRED = "isRequired";
}
